@@ -13,7 +13,6 @@ import grp
 import resource
 import stat
 import pkg_resources
-import select
 import glob
 import platform
 import warnings
@@ -48,6 +47,7 @@ from supervisor.datatypes import profile_options
 from supervisor import loggers
 from supervisor import states
 from supervisor import xmlrpc
+from supervisor import poller
 
 mydir = os.path.abspath(os.path.dirname(__file__))
 version_txt = os.path.join(mydir, 'version.txt')
@@ -100,7 +100,9 @@ class Options:
                        os.path.join(here, 'supervisord.conf'),
                        'supervisord.conf',
                        'etc/supervisord.conf',
-                       '/etc/supervisord.conf']
+                       '/etc/supervisord.conf',
+                       '/etc/supervisor/supervisord.conf',
+                       ]
         self.searchpaths = searchpaths
 
         self.environ_expansions = {}
@@ -403,7 +405,8 @@ class ServerOptions(Options):
     nodaemon = None
     environment = None
     httpservers = ()
-    unlink_socketfiles = True
+    unlink_pidfile = False
+    unlink_socketfiles = False
     mood = states.SupervisorStates.RUNNING
 
     def __init__(self):
@@ -447,7 +450,9 @@ class ServerOptions(Options):
         self.pidhistory = {}
         self.process_group_configs = []
         self.parse_warnings = []
+        self.parse_infos = []
         self.signal_receiver = SignalReceiver()
+        self.poller = poller.Poller(self)
 
     def version(self, dummy):
         """Print version to stdout and exit(0).
@@ -530,6 +535,7 @@ class ServerOptions(Options):
         # Clear parse warnings, since we may be re-reading the
         # config a second time after a reload.
         self.parse_warnings = []
+        self.parse_infos = []
 
         section = self.configroot.supervisord
         if not hasattr(fp, 'read'):
@@ -546,7 +552,9 @@ class ServerOptions(Options):
         except ConfigParser.ParsingError, why:
             raise ValueError(str(why))
 
-        expansions = {'here':self.here}
+        host_node_name = platform.node()
+        expansions = {'here':self.here,
+                      'host_node_name':host_node_name}
         expansions.update(self.environ_expansions)
         if parser.has_section('include'):
             if not parser.has_option('include', 'files'):
@@ -567,7 +575,7 @@ class ServerOptions(Options):
                         'No file matches via include "%s"' % pattern)
                     continue
                 for filename in sorted(filenames):
-                    self.parse_warnings.append(
+                    self.parse_infos.append(
                         'Included extra file "%s" during parsing' % filename)
                     try:
                         parser.read(filename)
@@ -793,7 +801,7 @@ class ServerOptions(Options):
                     socket_owner = (proc_uid, gid_for_uid(proc_uid))
 
             if socket_mode is None:
-                socket_mode = 0700
+                socket_mode = int('700', 8)
 
             return UnixStreamSocketConfig(path, owner=socket_owner,
                                                 mode=socket_mode)
@@ -1042,7 +1050,7 @@ class ServerOptions(Options):
                 except (TypeError, ValueError):
                     raise ValueError('Invalid chmod value %s' % chmod)
             else:
-                chmod = 0700
+                chmod = int('700', 8)
             config['chmod'] = chmod
             config['section'] = section
             configs.append(config)
@@ -1050,6 +1058,11 @@ class ServerOptions(Options):
         return configs
 
     def daemonize(self):
+        self.poller.before_daemonize()
+        self._daemonize()
+        self.poller.after_daemonize()
+
+    def _daemonize(self):
         # To daemonize, we need to become the leader of our own session
         # (process) group.  If we do not, signals sent to our
         # parent process will also be sent to us.   This might be bad because
@@ -1069,7 +1082,7 @@ class ServerOptions(Options):
         # change our umask.
         #
         # This explanation was (gratefully) garnered from
-        # http://www.hawklord.uklinux.net/system/daemons/d3.htm
+        # http://www.cems.uwe.ac.uk/~irjohnso/coursenotes/lrc/system/daemons/d3.htm
 
         pid = os.fork()
         if pid != 0:
@@ -1110,6 +1123,7 @@ class ServerOptions(Options):
         except (IOError, OSError):
             self.logger.critical('could not write pidfile %s' % self.pidfile)
         else:
+            self.unlink_pidfile = True
             self.logger.info('supervisord started with pid %s' % pid)
 
     def cleanup(self):
@@ -1118,7 +1132,9 @@ class ServerOptions(Options):
                 if self.unlink_socketfiles:
                     socketname = config['file']
                     self._try_unlink(socketname)
-        self._try_unlink(self.pidfile)
+        if self.unlink_pidfile:
+            self._try_unlink(self.pidfile)
+        self.poller.close()
 
     def _try_unlink(self, path):
         try:
@@ -1167,6 +1183,7 @@ class ServerOptions(Options):
     def openhttpservers(self, supervisord):
         try:
             self.httpservers = self.make_http_servers(supervisord)
+            self.unlink_socketfiles = True
         except socket.error, why:
             if why.args[0] == errno.EADDRINUSE:
                 self.usage('Another program is already listening on '
@@ -1181,7 +1198,6 @@ class ServerOptions(Options):
                 else:
                     self.usage('%s errno.%s (%d)' %
                                (help, errorname, why.args[0]))
-            self.unlink_socketfiles = False
         except ValueError, why:
             self.usage(why.args[0])
 
@@ -1223,9 +1239,6 @@ class ServerOptions(Options):
             except OSError:
                 pass
 
-    def select(self, r, w, x, timeout):
-        return select.select(r, w, x, timeout)
-
     def kill(self, pid, signal):
         os.kill(pid, signal)
 
@@ -1294,10 +1307,10 @@ class ServerOptions(Options):
         os.setuid(uid)
 
     def waitpid(self):
-        # Need pthread_sigmask here to avoid concurrent sigchild, but Python
+        # Need pthread_sigmask here to avoid concurrent sigchld, but Python
         # doesn't offer in Python < 3.4.  There is still a race condition here;
-        # we can get a sigchild while we're sitting in the waitpid call.
-        # However, AFAICT, if waitpid is interrupted bu SIGCHILD, as long as we
+        # we can get a sigchld while we're sitting in the waitpid call.
+        # However, AFAICT, if waitpid is interrupted by SIGCHLD, as long as we
         # call waitpid again (which happens every so often during the normal
         # course in the mainloop), we'll eventually reap the child that we
         # tried to reap during the interrupted call. At least on Linux, this
@@ -1305,12 +1318,14 @@ class ServerOptions(Options):
         # left zombies laying around.
         try:
             pid, sts = os.waitpid(-1, os.WNOHANG)
-        except OSError, why:
-            err = why.args[0]
-            if err not in (errno.ECHILD, errno.EINTR):
+        except OSError, exc:
+            code = exc.args[0]
+            if code not in (errno.ECHILD, errno.EINTR):
                 self.logger.critical(
-                    'waitpid error; a process may not be cleaned up properly')
-            if err == errno.EINTR:
+                    'waitpid error %r; '
+                    'a process may not be cleaned up properly' % code
+                    )
+            if code == errno.EINTR:
                 self.logger.blather('EINTR during reap')
             pid, sts = None, None
         return pid, sts
@@ -1460,7 +1475,7 @@ class ServerOptions(Options):
         elif stat.S_ISDIR(st[stat.ST_MODE]):
             raise NotExecutable("command at %r is a directory" % filename)
 
-        elif not (stat.S_IMODE(st[stat.ST_MODE]) & 0111):
+        elif not (stat.S_IMODE(st[stat.ST_MODE]) & int('111', 8)):
             raise NotExecutable("command at %r is not executable" % filename)
 
         elif not os.access(filename, os.X_OK):
@@ -2111,4 +2126,3 @@ class NoPermission(ProcessException):
     """ Indicates that the file cannot be executed because the supervisor
     process does not possess the appropriate UNIX filesystem permission
     to execute the file. """
-
