@@ -5,7 +5,7 @@
 Usage: %s [options] [action [arguments]]
 
 Options:
--c/--configuration FILENAME -- configuration file path (default /etc/supervisord.conf)
+-c/--configuration FILENAME -- configuration file path (searches if not given)
 -h/--help -- print usage message and exit
 -i/--interactive -- start an interactive shell after executing commands
 -s/--serverurl URL -- URL on which supervisord server is listening
@@ -67,9 +67,9 @@ class fgthread(threading.Thread):
 
     def run(self):
         self.output_handler.get(self.ctl.options.serverurl,
-                                '/logtail/%s/stdout'%self.program)
+                                '/logtail/%s/stdout' % self.program)
         self.error_handler.get(self.ctl.options.serverurl,
-                               '/logtail/%s/stderr'%self.program)
+                               '/logtail/%s/stderr' % self.program)
         asyncore.loop()
 
     def __run(self):
@@ -932,6 +932,11 @@ class DefaultControllerPlugin(ControllerPluginBase):
         self.ctl.output("shutdown \tShut the remote supervisord down.")
 
     def do_reload(self, arg):
+        if arg:
+            self.ctl.output('Error: reload accepts no arguments')
+            self.help_reload()
+            return
+
         if self.ctl.options.interactive:
             yesno = raw_input('Really restart the remote supervisord process '
                               'y/N? ')
@@ -986,6 +991,11 @@ class DefaultControllerPlugin(ControllerPluginBase):
         return template % formatted
 
     def do_avail(self, arg):
+        if arg:
+            self.ctl.output('Error: avail accepts no arguments')
+            self.help_avail()
+            return
+
         supervisor = self.ctl.get_supervisor()
         try:
             configinfo = supervisor.getAllConfigInfo()
@@ -1002,6 +1012,11 @@ class DefaultControllerPlugin(ControllerPluginBase):
         self.ctl.output("avail\t\t\tDisplay all configured processes")
 
     def do_reread(self, arg):
+        if arg:
+            self.ctl.output('Error: reread accepts no arguments')
+            self.help_reread()
+            return
+
         supervisor = self.ctl.get_supervisor()
         try:
             result = supervisor.reloadConfig()
@@ -1016,7 +1031,7 @@ class DefaultControllerPlugin(ControllerPluginBase):
             self._formatChanges(result[0])
 
     def help_reread(self):
-        self.ctl.output("reread \t\t\tReload the daemon's configuration files")
+        self.ctl.output("reread \t\t\tReload the daemon's configuration files without add/remove")
 
     def do_add(self, arg):
         names = arg.split()
@@ -1131,8 +1146,8 @@ class DefaultControllerPlugin(ControllerPluginBase):
             log(gname, "added process group")
 
     def help_update(self):
-        self.ctl.output("update\t\t\tReload config and add/remove as necessary")
-        self.ctl.output("update all\t\tReload config and add/remove as necessary")
+        self.ctl.output("update\t\t\tReload config and add/remove as necessary, and will restart affected programs")
+        self.ctl.output("update all\t\tReload config and add/remove as necessary, and will restart affected programs")
         self.ctl.output("update <gname> [...]\tUpdate specific groups")
 
     def _clearresult(self, result):
@@ -1200,6 +1215,11 @@ class DefaultControllerPlugin(ControllerPluginBase):
         self.ctl.output("\t\t(for UNIX domain socket, use unix:///socket/path)")
 
     def do_version(self, arg):
+        if arg:
+            self.ctl.output('Error: version accepts no arguments')
+            self.help_version()
+            return
+
         if not self.ctl.upcheck():
             return
         supervisor = self.ctl.get_supervisor()
@@ -1210,63 +1230,71 @@ class DefaultControllerPlugin(ControllerPluginBase):
             "version\t\t\tShow the version of the remote supervisord "
             "process")
 
-    def do_fg(self,args=None):
+    def do_fg(self, arg):
         if not self.ctl.upcheck():
             return
-        if not args:
-            self.ctl.output('Error: no process name supplied')
+
+        names = arg.split()
+        if not names:
+            self.ctl.output('ERROR: no process name supplied')
             self.help_fg()
             return
-        args = args.split()
-        if len(args) > 1:
-            self.ctl.output('Error: too many process names supplied')
+        if len(names) > 1:
+            self.ctl.output('ERROR: too many process names supplied')
             return
-        program = args[0]
+
+        name = names[0]
         supervisor = self.ctl.get_supervisor()
+
         try:
-            info = supervisor.getProcessInfo(program)
-        except xmlrpclib.Fault, msg:
-            if msg.faultCode == xmlrpc.Faults.BAD_NAME:
-                self.ctl.output('Error: bad process name supplied')
-                return
-            # for any other fault
-            self.ctl.output(str(msg))
+            info = supervisor.getProcessInfo(name)
+        except xmlrpclib.Fault, e:
+            if e.faultCode == xmlrpc.Faults.BAD_NAME:
+                self.ctl.output('ERROR: bad process name supplied')
+            else:
+                self.ctl.output('ERROR: ' + str(e))
             return
-        if not info['state'] == states.ProcessStates.RUNNING:
-            self.ctl.output('Error: process not running')
+
+        if info['state'] != states.ProcessStates.RUNNING:
+            self.ctl.output('ERROR: process not running')
             return
-        # everything good; continue
+
+        self.ctl.output('==> Press Ctrl-C to exit <==')
+
+        a = None
         try:
-            a = fgthread(program,self.ctl)
-            # this thread takes care of
-            # the output/error messages
+            # this thread takes care of the output/error messages
+            a = fgthread(name, self.ctl)
             a.start()
+
+            # this takes care of the user input
             while True:
-                # this takes care of the user input
                 inp = raw_input() + '\n'
                 try:
-                    supervisor.sendProcessStdin(program, inp)
-                except xmlrpclib.Fault, msg:
-                    if msg.faultCode == xmlrpc.Faults.NOT_RUNNING:
+                    supervisor.sendProcessStdin(name, inp)
+                except xmlrpclib.Fault, e:
+                    if e.faultCode == xmlrpc.Faults.NOT_RUNNING:
                         self.ctl.output('Process got killed')
-                        self.ctl.output('Exiting foreground')
-                        a.kill()
-                        return
-                info = supervisor.getProcessInfo(program)
-                if not info['state'] == states.ProcessStates.RUNNING:
+                    else:
+                        self.ctl.output('ERROR: ' + str(e))
+                    self.ctl.output('Exiting foreground')
+                    a.kill()
+                    return
+
+                info = supervisor.getProcessInfo(name)
+                if info['state'] != states.ProcessStates.RUNNING:
                     self.ctl.output('Process got killed')
                     self.ctl.output('Exiting foreground')
                     a.kill()
                     return
-                continue
         except (KeyboardInterrupt, EOFError):
-            a.kill()
             self.ctl.output('Exiting foreground')
-        return
+            if a:
+                a.kill()
 
     def help_fg(self,args=None):
         self.ctl.output('fg <process>\tConnect to a process in foreground mode')
-        self.ctl.output('Press Ctrl+C to exit foreground')
+        self.ctl.output("\t\tCtrl-C to exit")
 
 
 def main(args=None, options=None):
