@@ -175,12 +175,50 @@ class XMLRPCHandlerTests(unittest.TestCase):
         else:
             expected = 2
         self.assertEqual(len(logdata), expected)
-        self.assertEqual(logdata[-1],
-               u'XML-RPC request received with no method name')
-        self.assertEqual(len(request.producers), 0)
+        self.assertTrue(logdata[-1].startswith('XML-RPC request data'))
+        self.assertTrue(repr(data) in logdata[-1])
+        self.assertTrue(logdata[-1].endswith('is invalid: no method name'))
         self.assertEqual(request._error, 400)
 
-    def test_continue_request_500(self):
+    def test_continue_request_400_if_loads_raises_not_xml(self):
+        supervisor = DummySupervisor()
+        subinterfaces = [('supervisor', DummySupervisorRPCNamespace())]
+        handler = self._makeOne(supervisor, subinterfaces)
+        data = 'this is not an xml-rpc request body'
+        request = DummyRequest('/what/ever', None, None, None)
+        handler.continue_request(data, request)
+        logdata = supervisor.options.logger.data
+        from supervisor.xmlrpc import loads
+        if loads:
+            expected = 1
+        else:
+            expected = 2
+        self.assertEqual(len(logdata), expected)
+        self.assertTrue(logdata[-1].startswith('XML-RPC request data'))
+        self.assertTrue(repr(data) in logdata[-1])
+        self.assertTrue(logdata[-1].endswith('is invalid: unmarshallable'))
+        self.assertEqual(request._error, 400)
+
+    def test_continue_request_400_if_loads_raises_weird_xml(self):
+        supervisor = DummySupervisor()
+        subinterfaces = [('supervisor', DummySupervisorRPCNamespace())]
+        handler = self._makeOne(supervisor, subinterfaces)
+        data = '<methodName></methodName><junk></junk>'
+        request = DummyRequest('/what/ever', None, None, None)
+        handler.continue_request(data, request)
+        logdata = supervisor.options.logger.data
+        from supervisor.xmlrpc import loads
+        if loads:
+            expected = 1
+        else:
+            expected = 2
+        self.assertEqual(len(logdata), expected)
+        self.assertTrue(logdata[-1].startswith('XML-RPC request data'))
+        self.assertTrue(repr(data) in logdata[-1])
+        self.assertTrue(logdata[-1].endswith('is invalid: unmarshallable'))
+        self.assertEqual(request._error, 400)
+
+    def test_continue_request_500_if_rpcinterface_method_call_raises(self):
         supervisor = DummySupervisor()
         subinterfaces = [('supervisor', DummySupervisorRPCNamespace())]
         handler = self._makeOne(supervisor, subinterfaces)
@@ -197,11 +235,39 @@ class XMLRPCHandlerTests(unittest.TestCase):
         self.assertEqual(len(logdata), expected)
         self.assertEqual(logdata[-2],
                u'XML-RPC method called: supervisor.raiseError()')
-        self.assertTrue(logdata[-1].startswith('Traceback'))
-        self.assertTrue(logdata[-1].endswith('ValueError: error\n'))
+        self.assertTrue("unexpected exception" in logdata[-1])
+        self.assertTrue(repr(data) in logdata[-1])
+        self.assertTrue("Traceback" in logdata[-1])
+        self.assertTrue("ValueError: error" in logdata[-1])
         self.assertEqual(len(request.producers), 0)
         self.assertEqual(request._error, 500)
 
+    def test_continue_request_500_if_xmlrpc_dumps_raises(self):
+        supervisor = DummySupervisor()
+        subinterfaces = [('supervisor', DummySupervisorRPCNamespace())]
+        handler = self._makeOne(supervisor, subinterfaces)
+        import xmlrpclib
+        data = xmlrpclib.dumps((), 'supervisor.getXmlRpcUnmarshallable')
+        request = DummyRequest('/what/ever', None, None, None)
+        handler.continue_request(data, request)
+        logdata = supervisor.options.logger.data
+        from supervisor.xmlrpc import loads
+        if loads:
+            expected = 3
+        else:
+            expected = 4
+        self.assertEqual(len(logdata), expected)
+        self.assertEqual(logdata[-3],
+               'XML-RPC method called: supervisor.getXmlRpcUnmarshallable()')
+        self.assertEqual(logdata[-2],
+               'XML-RPC method supervisor.getXmlRpcUnmarshallable() '
+               'returned successfully')
+        self.assertTrue("unexpected exception" in logdata[-1])
+        self.assertTrue(repr(data) in logdata[-1])
+        self.assertTrue("Traceback" in logdata[-1])
+        self.assertTrue("TypeError: cannot marshal" in logdata[-1])
+        self.assertEqual(request._error, 500)
+
 class TraverseTests(unittest.TestCase):
     def test_underscore(self):
         from supervisor import xmlrpc
@@ -727,6 +793,23 @@ class Test_gettags(unittest.TestCase):
             [(0, None, None, None, ''), (0, 'foo', 'array', 'name', 'text')]
             )
 
+class Test_capped_int(unittest.TestCase):
+    def _callFUT(self, value):
+        from supervisor.xmlrpc import capped_int
+        return capped_int(value)
+
+    def test_converts_value_to_integer(self):
+        self.assertEqual(self._callFUT('42'), 42)
+
+    def test_caps_value_below_minint(self):
+        import xmlrpclib
+        self.assertEqual(self._callFUT(xmlrpclib.MININT - 1), xmlrpclib.MININT)
+
+    def test_caps_value_above_maxint(self):
+        import xmlrpclib
+        self.assertEqual(self._callFUT(xmlrpclib.MAXINT + 1), xmlrpclib.MAXINT)
+
+
 class DummyResponse:
     def __init__(self, status=200, body='', reason='reason'):
         self.status = status
